@@ -65,6 +65,8 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     private final ThreadPoolExecutor mThreadPool = new ThreadPoolExecutor(1, 1, 30, TimeUnit.SECONDS,
             new LinkedBlockingQueue<Runnable>(), VLCApplication.THREAD_FACTORY);
+    private final ThreadPoolExecutor mNotificationThreadPool = new ThreadPoolExecutor(1, 1, 2, TimeUnit.SECONDS,
+            new LinkedBlockingQueue<Runnable>(), VLCApplication.THREAD_FACTORY);
 
     boolean mScanPaused = false;
     private BroadcastReceiver mReceiver = new BroadcastReceiver() {
@@ -148,6 +150,8 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     private void discoverStorage(final String path) {
         if (BuildConfig.DEBUG) Log.d(TAG, "discoverStorage: "+path);
+        if (TextUtils.isEmpty(path))
+            return;
         mThreadPool.execute(new Runnable() {
             @Override
             public void run() {
@@ -172,14 +176,14 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
 
     private void addDeviceIfNeeded(String path) {
         for (String devicePath : mMedialibrary.getDevices()) {
-            if (path.startsWith(devicePath))
+            if (path.startsWith(Strings.removeFileProtocole(devicePath)))
                 return;
         }
         for (String storagePath : AndroidDevices.getExternalStorageDirectories()) {
             if (path.startsWith(storagePath)) {
                 String uuid = FileUtils.getFileNameFromPath(path);
-                if (TextUtils.isEmpty(uuid))
-                    uuid = "root";
+                if (TextUtils.isEmpty(path) || TextUtils.isEmpty(uuid))
+                    return;
                 mMedialibrary.addDevice(uuid, path, true, true);
                 for (String folder : Medialibrary.getBlackList())
                     mMedialibrary.banFolder(path + folder);
@@ -212,6 +216,8 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                         for (String device : devices) {
                             boolean isMainStorage = TextUtils.equals(device, AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
                             String uuid = FileUtils.getFileNameFromPath(device);
+                            if (TextUtils.isEmpty(device) || TextUtils.isEmpty(uuid))
+                                continue;
                             boolean isNew = mMedialibrary.addDevice(isMainStorage ? "main-storage" : uuid, device, !isMainStorage, false);
                             boolean isIgnored = sharedPreferences.getBoolean("ignore_"+ uuid, false);
                             if (!isMainStorage && isNew && !isIgnored) {
@@ -249,7 +255,7 @@ public class MediaParsingService extends Service implements DevicesDiscoveryCb {
                 return;
             mLastNotificationTime = currentTime;
         }
-        VLCApplication.runBackground(new Runnable() {
+        mNotificationThreadPool.execute(new Runnable() {
             @Override
             public void run() {
                 sb.setLength(0);
