@@ -2,7 +2,7 @@ package org.videolan.vlc.extensions;
 
 import android.net.Uri;
 
-import org.videolan.vlc.media.MediaWrapper;
+import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.extensions.api.VLCExtensionItem;
 
 public class Utils {
