@@ -36,15 +36,18 @@ import android.support.annotation.NonNull;
 import android.support.annotation.Nullable;
 import android.support.design.widget.AppBarLayout;
 import android.support.design.widget.BottomSheetBehavior;
+import android.support.design.widget.CoordinatorLayout;
 import android.support.v4.app.Fragment;
 import android.support.v4.app.FragmentManager;
 import android.support.v4.content.LocalBroadcastManager;
+import android.support.v7.preference.PreferenceManager;
 import android.support.v7.widget.Toolbar;
 import android.support.v7.widget.ViewStubCompat;
 import android.view.MenuItem;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.FrameLayout;
+import android.widget.ProgressBar;
 import android.widget.TextView;
 
 import org.videolan.vlc.BuildConfig;
@@ -81,19 +84,19 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
     protected PlaybackService mService;
     protected BottomSheetBehavior mBottomSheetBehavior;
     protected View mFragmentContainer;
+    private View mScanProgressLayout;
+    private TextView mScanProgressText;
+    private ProgressBar mScanProgressBar;
 
     protected boolean mPreventRescan = false;
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
-
         MediaUtils.updateSubsDownloaderActivity(this);
-
         super.onCreate(savedInstanceState);
     }
 
     protected void initAudioPlayerContainerActivity() {
-
         mToolbar = (Toolbar) findViewById(R.id.main_toolbar);
         setSupportActionBar(mToolbar);
         mAppBarLayout = (AppBarLayout) findViewById(R.id.appbar);
@@ -130,9 +133,13 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
         registerReceiver(storageReceiver, storageFilter);
 
         /* Prepare the progressBar */
-        IntentFilter filter = new IntentFilter();
-        filter.addAction(ACTION_SHOW_PLAYER);
-        registerReceiver(messageReceiver, filter);
+        IntentFilter playerFilter = new IntentFilter();
+        playerFilter.addAction(ACTION_SHOW_PLAYER);
+        registerReceiver(messageReceiver, playerFilter);
+        IntentFilter progressFilter = new IntentFilter(MediaParsingService.ACTION_SERVICE_STARTED);
+        progressFilter.addAction(MediaParsingService.ACTION_SERVICE_ENDED);
+        progressFilter.addAction(MediaParsingService.ACTION_PROGRESS);
+        LocalBroadcastManager.getInstance(this).registerReceiver(messageReceiver, progressFilter);
     }
 
     @Override
@@ -144,8 +151,10 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
     @Override
     protected void onResume() {
         super.onResume();
-        if (mBottomSheetBehavior != null && mBottomSheetBehavior.getState() == BottomSheetBehavior.STATE_COLLAPSED)
+        if (mBottomSheetBehavior != null && mBottomSheetBehavior.getState() == BottomSheetBehavior.STATE_COLLAPSED) {
             mFragmentContainer.setPadding(0, 0, 0, mBottomSheetBehavior.getPeekHeight());
+            applyMarginToProgressBar(mBottomSheetBehavior.getPeekHeight());
+        }
     }
 
     @Override
@@ -153,6 +162,7 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
         super.onStop();
         unregisterReceiver(storageReceiver);
         unregisterReceiver(messageReceiver);
+        LocalBroadcastManager.getInstance(this).unregisterReceiver(messageReceiver);
         mHelper.onStop();
     }
 
@@ -199,9 +209,9 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
     public void showTipViewIfNeeded(final int stubId, final String settingKey) {
         if (BuildConfig.DEBUG)
             return;
-        ViewStubCompat vsc = (ViewStubCompat) findViewById(stubId);
+        View vsc = findViewById(stubId);
         if (vsc != null && !mSettings.getBoolean(settingKey, false) && !VLCApplication.showTvUi()) {
-            View v = vsc.inflate();
+            View v = ((ViewStubCompat)vsc).inflate();
             v.setOnClickListener(new View.OnClickListener() {
                 @Override
                 public void onClick(View v) {
@@ -238,6 +248,7 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
         if (mAudioPlayerContainer.getVisibility() == View.GONE) {
             mAudioPlayerContainer.setVisibility(View.VISIBLE);
             mFragmentContainer.setPadding(0, 0, 0, mBottomSheetBehavior.getPeekHeight());
+            applyMarginToProgressBar(mBottomSheetBehavior.getPeekHeight());
         }
         if (mBottomSheetBehavior.getState() == BottomSheetBehavior.STATE_HIDDEN) {
             mBottomSheetBehavior.setState(BottomSheetBehavior.STATE_COLLAPSED);
@@ -280,12 +291,58 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
         mBottomSheetBehavior.setState(BottomSheetBehavior.STATE_HIDDEN);
     }
 
+    private void updateProgressVisibility(int visibility) {
+        boolean show = visibility == View.VISIBLE;
+        if ((mScanProgressLayout == null && !show) ||
+                (mScanProgressLayout != null && mScanProgressLayout.getVisibility() == visibility))
+            return;
+        if (show)
+            mActivityHandler.sendEmptyMessageDelayed(ACTION_DISPLAY_PROGRESSBAR, 1000);
+        else if (mScanProgressLayout != null)
+            mScanProgressLayout.setVisibility(visibility);
+    }
+
+    private void showProgressBar() {
+        View vsc = findViewById(R.id.scan_viewstub);
+        if (vsc != null) {
+            vsc.setVisibility(View.VISIBLE);
+            mScanProgressLayout = findViewById(R.id.scan_progress_layout);
+            mScanProgressText = (TextView) findViewById(R.id.scan_progress_text);
+            mScanProgressBar = (ProgressBar) findViewById(R.id.scan_progress_bar);
+            if (mBottomSheetBehavior != null && mBottomSheetBehavior.getState() == BottomSheetBehavior.STATE_COLLAPSED) {
+                mFragmentContainer.setPadding(0, 0, 0, mBottomSheetBehavior.getPeekHeight());
+                applyMarginToProgressBar(mBottomSheetBehavior.getPeekHeight());
+            }
+        } else if (mScanProgressLayout != null)
+            mScanProgressLayout.setVisibility(View.VISIBLE);
+    }
+
+    private void applyMarginToProgressBar(int marginValue) {
+        if (mScanProgressLayout != null && mScanProgressLayout.getVisibility() == View.VISIBLE) {
+            CoordinatorLayout.LayoutParams lp = (CoordinatorLayout.LayoutParams) mScanProgressLayout.getLayoutParams();
+            lp.bottomMargin = marginValue;
+            mScanProgressLayout.setLayoutParams(lp);
+        }
+    }
+
     private final BroadcastReceiver messageReceiver = new BroadcastReceiver() {
         @Override
         public void onReceive(Context context, Intent intent) {
             String action = intent.getAction();
-            if (action.equalsIgnoreCase(ACTION_SHOW_PLAYER))
+            if (ACTION_SHOW_PLAYER.equals(action))
                 showAudioPlayer();
+            else if (MediaParsingService.ACTION_SERVICE_STARTED.equals(action))
+                updateProgressVisibility(View.VISIBLE);
+            else if (MediaParsingService.ACTION_SERVICE_ENDED.equals(action)) {
+                mActivityHandler.removeMessages(ACTION_DISPLAY_PROGRESSBAR);
+                updateProgressVisibility(View.GONE);
+            } else if (MediaParsingService.ACTION_PROGRESS.equals(action)) {
+                updateProgressVisibility(View.VISIBLE);
+                if (mScanProgressText != null)
+                    mScanProgressText.setText(intent.getStringExtra(MediaParsingService.ACTION_PROGRESS_TEXT));
+                if (mScanProgressBar != null)
+                    mScanProgressBar.setProgress(intent.getIntExtra(MediaParsingService.ACTION_PROGRESS_VALUE, 0));
+            }
         }
     };
 
@@ -305,6 +362,7 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
 
     private static final int ACTION_MEDIA_MOUNTED = 1337;
     private static final int ACTION_MEDIA_UNMOUNTED = 1338;
+    private static final int ACTION_DISPLAY_PROGRESSBAR = 1339;
 
     public boolean isAudioPlayerReady() {
         return mAudioPlayer != null;
@@ -323,10 +381,12 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
                 case BottomSheetBehavior.STATE_COLLAPSED:
                     removeTipViewIfDisplayed();
                     mFragmentContainer.setPadding(0, 0, 0, mBottomSheetBehavior.getPeekHeight());
+                    applyMarginToProgressBar(mBottomSheetBehavior.getPeekHeight());
                     break;
                 case BottomSheetBehavior.STATE_HIDDEN:
                     removeTipViewIfDisplayed();
                     mFragmentContainer.setPadding(0, 0, 0, 0);
+                    applyMarginToProgressBar(0);
                     break;
             }
         }
@@ -349,24 +409,32 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
             AudioPlayerContainerActivity owner = getOwner();
             if (owner == null)
                 return;
-            String uuid = ((Uri) msg.obj).getLastPathSegment();
+            String uuid;
             switch (msg.what){
                 case ACTION_MEDIA_MOUNTED:
+                    uuid = ((Uri) msg.obj).getLastPathSegment();
                     String path = ((Uri) msg.obj).getPath();
                     removeMessages(ACTION_MEDIA_UNMOUNTED);
-                    if (VLCApplication.getMLInstance().addDevice(uuid, path, true)) {
-                        owner.startActivity(new Intent(owner, DialogActivity.class)
-                                .setAction(DialogActivity.KEY_STORAGE)
-                                .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
-                                .putExtra(MediaParsingService.EXTRA_PATH, path));
-                    } else
-                        owner.startService(new Intent(MediaParsingService.ACTION_RELOAD, null, owner, MediaParsingService.class)
-                            .putExtra(MediaParsingService.EXTRA_PATH, path));
+                    if (!PreferenceManager.getDefaultSharedPreferences(owner).getBoolean("ignore_"+ uuid, false)) {
+                        if (VLCApplication.getMLInstance().addDevice(uuid, path, true, true)) {
+                            owner.startActivity(new Intent(owner, DialogActivity.class)
+                                    .setAction(DialogActivity.KEY_STORAGE)
+                                    .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
+                                    .putExtra(MediaParsingService.EXTRA_PATH, path));
+                        } else
+                            owner.startService(new Intent(MediaParsingService.ACTION_RELOAD, null, owner, MediaParsingService.class)
+                                    .putExtra(MediaParsingService.EXTRA_PATH, path));
+                    }
                     break;
                 case ACTION_MEDIA_UNMOUNTED:
+                    uuid = ((Uri) msg.obj).getLastPathSegment();
                     VLCApplication.getMLInstance().removeDevice(uuid);
                     LocalBroadcastManager.getInstance(owner).sendBroadcast(new Intent(MediaParsingService.ACTION_SERVICE_ENDED));
                     break;
+                case ACTION_DISPLAY_PROGRESSBAR:
+                    removeMessages(ACTION_DISPLAY_PROGRESSBAR);
+                    owner.showProgressBar();
+                    break;
             }
         }
     }
